componenttools.all_are_contiguous_components_in_same_score
==========================================================

.. autofunction:: abjad.tools.componenttools.all_are_contiguous_components_in_same_score.all_are_contiguous_components_in_same_score
